\encoding{latin1}
\name{H2fun}

\alias{H2fun}

\title{ Specialisation of a bipartite web. }

\description{
  Calculates the overall level of specialisation of all partners in a bipartite web.
}
\usage{
H2fun(web)
}

\arguments{
  \item{web}{ A matrix representing the interactions observed between higher trophic
  level species (columns) and lower trophic level species (rows). Usually this will
  be number of pollinators on each species of plants or number of parasitoids on
  each species of prey. }
}

\details{
  H2' is an index describing the level of specialisation, or should one say: selectiveness,
  of an entire bipartite network (Blthgen et al. 2006). It describes to which extent
  observed interactions deviate from those that would be expected given the species
  marginal sums. The more selective a species, the larger is H2' for the web. 
  
  H2' is an extension of d' (see \code{\link{dfun}}) for the entire network. Check
  there for details on finding maximum and minimum H2 values for a given web.
  
  For internet implementation see also: \url{http://nils.mib.man.ac.uk/~nils/stat/}
}

\value{
  \item{H2}{The H2'-value for the web matrix.}
  \item{H2min}{Heuristic minimum H2-value for the web matrix.}
  \item{H2max}{Heuristic maximum H2-value for the web matrix.}
  \item{H2uncorr}{Uncorrected H2-values (before ranging between min and max), rounded
  to three digits.}
}

\references{ 
Blthgen, N., Menzel, F. and Blthgen, N. (2006) Measuring specialization in species
interaction networks. \emph{BMC Ecology} \bold{6}, 9

 }

\author{ Carsten F. Dormann and Jochen Frnd }

\seealso{ \code{\link{dfun}} doing the same for each species in the web matrix. }

\examples{
data(Safariland)
H2fun(Safariland)
}

\keyword{ package }

